/*
 * Copyright (c) 2020 Nordic Semiconductor ASA
 *
 * SPDX-License-Identifier: Apache-2.0
 */

// modified periodic_sync example of ncs to test "pure" extended advertising

#include <device.h>
#include <devicetree.h>
#include <drivers/gpio.h>
#include <bluetooth/bluetooth.h>

/* prj.conf:
 * CONFIG_BT=y
 * CONFIG_BT_EXT_ADV=y
 * CONFIG_BT_OBSERVER=y
 * CONFIG_BT_PER_ADV_SYNC=n
 * CONFIG_BT_DEBUG_LOG=y
 * CONFIG_BT_DEVICE_NAME="Test Reception of Extended Adv"
 * CONFIG_BT_CTLR=y
 * CONFIG_BT_HCI=y
 * CONFIG_BT_CTLR_PHY_2M=y
 * CONFIG_BT_CTLR_PHY_CODED=y
 * CONFIG_BT_CTLR_SCAN_DATA_LEN_MAX=1650
 * CONFIG_BT_EXT_SCAN_BUF_SIZE=1650
 */

static void scan_recv(const struct bt_le_scan_recv_info *info,
		      struct net_buf_simple *buf)
{
	if ((buf->data[3] == 0xff) && (buf->data[5] == 0xbb)){   // i.e. my frames
		printk("Adv type : %d \n", info->adv_type);
		printk("net_buf_simple_max_length: %u\n", net_buf_simple_max_len(buf));
		printk("    %.2X %.2X %.2X\n", buf->data[3], buf->data[4], buf->data[5]);
		for(int i = 0; i < 254; i++){
			//Just to check output
		  	printk("\n %.2X",  buf->data[i]);
		}
	}
}

static struct bt_le_scan_cb scan_callbacks = {
	.recv = scan_recv,
};

void main(void)
{
	int err;

	printk("Starting Axel's Extended Advertising Reception Demo\n");
	printk("\n");
	printk("CONFIG_BT_CTLR_ADV_DATA_LEN_MAX : %d\n", CONFIG_BT_CTLR_ADV_DATA_LEN_MAX);
	printk("CONFIG_BT_CTLR_SCAN_DATA_LEN_MAX: %d\n", CONFIG_BT_CTLR_SCAN_DATA_LEN_MAX);
	printk("\n");


	/* Initialize the Bluetooth Subsystem */
	err = bt_enable(NULL);
	if (err) {
		printk("Bluetooth init failed (err %d)\n", err);
		return;
	}

	printk("Scan callbacks register...");
	bt_le_scan_cb_register(&scan_callbacks);
	printk("success.\n");


	printk("Start scanning...");
	err = bt_le_scan_start(BT_LE_SCAN_ACTIVE , NULL);
	//err = bt_le_scan_start(BT_LE_SCAN_PASSIVE, NULL);
	if (err) {
		printk("failed (err %d)\n", err);
		return;
	}
	printk("success.\n");

	do {
	} while (true);
}
